@@ -229,7 +229,7 @@ class HexViewWidget(object):
         encoding_menu.show()
         item.set_submenu(encoding_menu)
 
-        config_encoding = mobius.core.get_config('gtk-ui-hexview.encoding') or 'cp850'
+        config_encoding = mobius.framework.get_config('gtk-ui-hexview.encoding') or 'cp850'
         group_menuitem = None
 
         for encoding in ENCODINGS:
@@ -252,7 +252,7 @@ class HexViewWidget(object):
         bytes_per_line_menu.show()
         item.set_submenu(bytes_per_line_menu)
 
-        config_bytes_per_line = mobius.core.get_config('gtk-ui-hexview.bytes_per_line') or 16
+        config_bytes_per_line = mobius.framework.get_config('gtk-ui-hexview.bytes_per_line') or 16
         group_menuitem = None
 
         for bytes_per_line in BYTES_PER_LINE:
@@ -489,8 +489,8 @@ class HexViewWidget(object):
             textbuffer = self.__textview.get_buffer()
             textbuffer.set_encoding(encoding)
 
-            transaction = mobius.core.new_config_transaction()
-            mobius.core.set_config('gtk-ui-hexview.encoding', encoding)
+            transaction = mobius.framework.new_config_transaction()
+            mobius.framework.set_config('gtk-ui-hexview.encoding', encoding)
             transaction.commit()
 
     # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
@@ -501,8 +501,8 @@ class HexViewWidget(object):
             textbuffer = self.__textview.get_buffer()
             textbuffer.width = bytes_per_line
 
-            transaction = mobius.core.new_config_transaction()
-            mobius.core.set_config('gtk-ui-hexview.bytes_per_line', bytes_per_line)
+            transaction = mobius.framework.new_config_transaction()
+            mobius.framework.set_config('gtk-ui-hexview.bytes_per_line', bytes_per_line)
             transaction.commit()
 
     # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
